Histogram Plot

Enter column name (column name must be contained in the data file)
Enter [min:max:]bins (use '0' to specify the default number of bins)
Use bin width instead of number of bins?
Normalize by bin size?

Help for Histogram Plot

The histogram plot task will create a 1D histogram from the specfied column and display it as a plot. Of course, the column name is required and must be contained in the data file.

The required bin parameter specifies the number of bins to use in creating the histogram and, if desired, the range of bin values. The range should specify the desired min and max data values. If this argument is omitted, the number of output bins is calculated either from the TLMIN/TLMAX headers values (if these exist in the table FITS header for the specified column) or by going through the data to calculate the min and max value.

The optional bin width parameter can be used to specify the width of each bin rather than the number of bins. Without bin width, a bin value of 1:100:5 means that 5 bins of width 20 are used in the histogram. Using bin width, a bin value of 1:100:5 means that 20 bins of width 5 are used in the histogram.

The optional normalize parameter can be used to normalize the bin value by the width of the bin. This could used, for example, to produce a light curve with values having units of counts/second instead of counts.